package dk.apaq.crud.vaadin;

import com.vaadin.data.Container.Sortable;
import dk.apaq.crud.Crud;
import dk.apaq.crud.HasId;
import dk.apaq.filter.sort.SortDirection;
import dk.apaq.filter.sort.Sorter;
import dk.apaq.filter.sort.SorterEntry;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;


/**
 * Crud container that implements <code>Sortable</code>. This makes it possible to easily have
 * a Vaadin table sort on columns and have the data sorted directly in the Crud backend.
 */
public class SortableCrudContainer<IDT, BT extends HasId<IDT>> extends CrudContainer<IDT, BT>
        implements Sortable{

    private final Crud.Filterable<IDT, BT> filterableCrud;

    public SortableCrudContainer(Crud.Filterable<IDT, BT> crud, Class beanClass) {
        super(crud, beanClass);
        this.filterableCrud = crud;
    }

    @Override
    public void sort(Object[] propertyId, boolean[] ascending) {
        List<SorterEntry> sorterEntries = new ArrayList<SorterEntry>();

        for(int i=0; i<propertyId.length; i++) {
            String id = propertyId[i].toString();
            SortDirection direction = ascending[i] ? SortDirection.Ascending : SortDirection.Descending;
            sorterEntries.add(new SorterEntry(id, direction));
        }
        setSorter(new Sorter(sorterEntries));
    }

    @Override
    public Collection<?> getSortableContainerPropertyIds() {
        return getContainerPropertyIds();
    }


}
